==> aiclubiuh-0.0.1.tar.gz: aiclubiuh-0.0.1/README.md <==
# aiclubiuh

**AI_Club - Câu lạc bộ Trí tuệ nhân tạo IUH**

## Giới thiệu

`aiclubiuh` là thư viện Python đại diện cho Câu lạc bộ Trí tuệ Nhân tạo của Trường Đại học Công nghiệp TP.HCM (IUH). 
Câu lạc bộ được thành lập từ năm 2019, tọa lạc tại phòng Data Innovation Lab H2.2. Đây là nơi dành cho các sinh viên yêu thích và đam mê nghiên cứu trong lĩnh vực Khoa học Dữ liệu (KHDL) và Khoa học Máy tính (KHMT), tạo ra một môi trường học tập năng động và sân chơi học thuật để phát triển kỹ năng và kiến thức chuyên môn.

**Hoạt động chính:**
- Tham gia các khóa học miễn phí về Lập trình, Toán học, Trí tuệ Nhân tạo.
- Nghiên cứu khoa học và tham dự hội nghị.
- Tham gia các hoạt động giải trí như văn nghệ và thể thao.

**Trang thiết bị:**
- Phòng lab hiện đại tại Data Innovation Lab H2.2, Trường Đại học Công nghiệp TP.HCM.

**Đối tượng:**
- Tất cả sinh viên đam mê AI, khoa học dữ liệu, không phân biệt ngành học.

**Lý do tham gia:**
- Học hỏi từ giảng viên, mentor và tham gia các cuộc thi lớn.
- Tham gia các workshop, seminar và các hoạt động kết nối.
- Cơ hội học hỏi kinh nghiệm từ các anh chị khóa trước.

Hãy cùng tham gia AI Club để phát triển bản thân và khám phá những tiềm năng mới!

## Liên hệ

- **Website**: [main.aiclubiuh.com](https://main.aiclubiuh.com)
- **Blog**: [AI Wiki](https://aiwiki.github.io/)
- **Facebook**: [AI Club - Khoa Học Dữ Liệu IUH](https://www.facebook.com/aiclub.iuh)
- **Nhóm Facebook**: [Khoa Học Dữ Liệu IUH](https://www.facebook.com/groups/khdl.iuh)
- **Email**: aiclub.iuh@gmail.com

## Cài đặt

Bạn có thể cài đặt thư viện này từ Test PyPI hoặc PyPI bằng cách sử dụng pip:

```bash
pip install -i https://test.pypi.org/simple/ aiclubiuh
```
hoặc

```bash
pip install aiclubiuh
```

## Sử dụng

```python
import aiclubiuh
```

==> aiclubiuh-0.0.2.tar.gz: aiclubiuh-0.0.2/README.md <==
# aiclubiuh

**AI_Club - Câu lạc bộ Trí tuệ nhân tạo IUH**

## Giới thiệu

`aiclubiuh` là thư viện Python đại diện cho Câu lạc bộ Trí tuệ Nhân tạo của Trường Đại học Công nghiệp TP.HCM (IUH). 
Câu lạc bộ được thành lập từ năm 2019, tọa lạc tại phòng Data Innovation Lab H2.2. Đây là nơi dành cho các sinh viên yêu thích và đam mê nghiên cứu trong lĩnh vực Khoa học Dữ liệu (KHDL) và Khoa học Máy tính (KHMT), tạo ra một môi trường học tập năng động và sân chơi học thuật để phát triển kỹ năng và kiến thức chuyên môn.

**Hoạt động chính:**
- Tham gia các khóa học miễn phí về Lập trình, Toán học, Trí tuệ Nhân tạo.
- Nghiên cứu khoa học và tham dự hội nghị.
- Tham gia các hoạt động giải trí như văn nghệ và thể thao.

**Trang thiết bị:**
- Phòng lab hiện đại tại Data Innovation Lab H2.2, Trường Đại học Công nghiệp TP.HCM.

**Đối tượng:**
- Tất cả sinh viên đam mê AI, khoa học dữ liệu, không phân biệt ngành học.

**Lý do tham gia:**
- Học hỏi từ giảng viên, mentor và tham gia các cuộc thi lớn.
- Tham gia các workshop, seminar và các hoạt động kết nối.
- Cơ hội học hỏi kinh nghiệm từ các anh chị khóa trước.

Hãy cùng tham gia AI Club để phát triển bản thân và khám phá những tiềm năng mới!

## Liên hệ

- **Website**: [main.aiclubiuh.com](https://main.aiclubiuh.com)
- **Blog**: [AI Wiki](https://aiwiki.github.io/)
- **Facebook**: [AI Club - Khoa Học Dữ Liệu IUH](https://www.facebook.com/aiclub.iuh)
- **Nhóm Facebook**: [Khoa Học Dữ Liệu IUH](https://www.facebook.com/groups/khdl.iuh)
- **Email**: aiclub.iuh@gmail.com

## Cài đặt

Bạn có thể cài đặt thư viện này từ Test PyPI hoặc PyPI bằng cách:

```bash
pip install aiclubiuh
```
hoặc 

```bash
pip install -i https://test.pypi.org/simple/ aiclubiuh
```

## Sử dụng

```python
import aiclubiuh
```
